@@ -1,9 +1,10 @@
 import inspect
+import logging
 from typing import Any, Callable, Dict
 
 from pydantic import BaseModel, Field, PrivateAttr
 
-from motion.utils import logger
+logger = logging.getLogger(__name__)
 
 
 class Route(BaseModel):
@@ -30,7 +31,7 @@ class Route(BaseModel):
         try:
             result = self.udf(**filtered_kwargs)
         except Exception as e:
-            logger.error(f"Error in {self.key} flow: {e}")
+            logger.error(f"Error in {self.key}, {self.op} flow: {e}")
             raise e
 
         return result
